#
# spec file for package lua-lmod
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
%define ohpc 0

%define lua_lmod_modulesdir %{_datarootdir}/lmod/modulefiles
%define lua_lmod_admin_modulesdir %{_datarootdir}/lmod/admin/modulefiles
%define lua_lmod_moduledeps %{_datarootdir}/lmod/moduledeps
%define lua_path ?.lua;?/?.lua;%{lua_noarchdir}/?.lua;%{lua_noarchdir}/?/init.lua
%define lua_cpath ?.so;?/?.so;%{lua_archdir}/?.so

Name:           lua-lmod
Summary:        Lua-based Environment Modules
License:        MIT
Group:          Development/Libraries/Other
Version:        7.6.1
Release:        lp150.3.3
Url:            https://github.com/TACC/Lmod
%if 0%{?ohpc}
BuildRequires:  ohpc
%endif

Source0:        https://github.com/TACC/Lmod/archive/%{version}.tar.gz#$/%{name}-%{version}.tar.gz
Patch1:         Messages-Remove-message-about-creating-a-consulting-ticket.patch
Patch2:         Doc-Ugly-workaround-for-bug-in-Sphinx.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

BuildRequires:  lua >= %{lua_version}
BuildRequires:  lua-devel >= %{lua_version}
BuildRequires:  lua-luafilesystem
BuildRequires:  lua-luaposix
BuildRequires:  lua-luaterm
BuildRequires:  procps
BuildRequires:  python-Sphinx
BuildRequires:  rsync
BuildRequires:  tcl
BuildRequires:  texlive
BuildRequires:  texlive-babel
BuildRequires:  texlive-babel-english
BuildRequires:  texlive-capt-of
BuildRequires:  texlive-caption
BuildRequires:  texlive-cmap
BuildRequires:  texlive-courier
BuildRequires:  texlive-dvips
BuildRequires:  texlive-eqparbox
BuildRequires:  texlive-fancybox
BuildRequires:  texlive-fancyhdr
BuildRequires:  texlive-fancyvrb
BuildRequires:  texlive-framed
BuildRequires:  texlive-helvetic
BuildRequires:  texlive-latexmk
BuildRequires:  texlive-makeindex
BuildRequires:  texlive-mdwtools
BuildRequires:  texlive-multirow
BuildRequires:  texlive-needspace
BuildRequires:  texlive-parskip
BuildRequires:  texlive-psnfss
BuildRequires:  texlive-threeparttable
BuildRequires:  texlive-times
BuildRequires:  texlive-titlesec
BuildRequires:  texlive-upquote
BuildRequires:  texlive-varwidth
BuildRequires:  texlive-wrapfig
Requires:       lua >= %{lua_version}
Requires:       lua-luafilesystem
Requires:       lua-luaposix
Requires:       lua-luaterm
Requires:       tcl
Conflicts:      Modules
%if 0%{?sle_version} == 0 || 0%{?sle_version} >= 120300
BuildRequires:  python-Sphinx-latex
%endif

%description
Lmod is an Environment Module System based on Lua, Reads TCL Modules,
Supports a Software Hierarchy.

%package doc
Summary:        Documentation for Lmod
Group:          Documentation/PDF

%description doc
Documentation (PDF) for the Lmod Environment Modules System.

%prep
%setup -q -n Lmod-%{version}
%patch1 -p1
%if 0%{?sle_version:1} && 0%{?sle_version} < 150000
%patch2 -p1
%endif

%build
export LUA_CPATH="%{lua_cpath}"
export LUA_PATH="%{lua_path}"
%configure --prefix=%{_datadir} \
    --with-module-root-path=%{lua_lmod_modulesdir} \
    --libdir=%{lua_archdir} \
    --datadir=%{lua_noarchdir} \
    --with-redirect=yes \
    --with-autoSwap=no
make
find my_docs/ -name .gitignore -delete
cd docs; make latexpdf man; cd ..

%install
export LUA_CPATH="%{lua_cpath}"
export LUA_PATH="%{lua_path}"
%make_install

mkdir -p %{buildroot}%{_sysconfdir}/rpm
cat <<EOF > %{buildroot}%{_sysconfdir}/rpm/macros.lmod
%%lua_lmod_modulesdir %{lua_lmod_modulesdir}
%%lua_lmod_admin_modulesdir %{lua_lmod_admin_modulesdir}
%%lua_lmod_moduledeps %{lua_lmod_moduledeps}
EOF
mkdir -p %{buildroot}%{lua_lmod_modulesdir}
mkdir -p %{buildroot}%{lua_lmod_admin_modulesdir}
mkdir -p %{buildroot}%{lua_lmod_moduledeps}
mkdir -p %{buildroot}/%{_mandir}/man1                                                       
install -p -m644 docs/build/man/lmod.1 %{buildroot}/%{_mandir}/man1/

# Fix exec warning
chmod u+x %{buildroot}%{_datadir}/lmod/%{version}/libexec/ignore_dirs_converter
# Fix file duplicates
rm -f %{buildroot}/%{_datadir}/lmod/%{version}/init/ksh
ln -s %{_datadir}/lmod/%{version}/init/sh  %{buildroot}/%{_datadir}/lmod/%{version}/init/ksh
rm -f %{buildroot}/%{_datadir}/lmod/%{version}/init/zsh
ln -s %{_datadir}/lmod/%{version}/init/bash  %{buildroot}/%{_datadir}/lmod/%{version}/init/zsh
rm -f %{buildroot}/%{_datadir}/lmod/%{version}/init/tcsh
ln -s %{_datadir}/lmod/%{version}/init/csh %{buildroot}/%{_datadir}/lmod/%{version}/init/tcsh
rm -f %{buildroot}/%{_datadir}/lmod/%{version}/settarg/Version.lua 
ln -s %{_datadir}/lmod/%{version}/libexec/Version.lua %{buildroot}/%{_datadir}/lmod/%{version}/settarg/Version.lua

mkdir -p %{buildroot}/%{_sysconfdir}/profile.d
cat <<EOF >%{buildroot}/%{_sysconfdir}/profile.d/lmod.sh
# -*- shell-script -*-
########################################################################
#  This is the system wide source file for setting up
#  modules:
#
########################################################################

# NOOP if running under known resource manager
if [ ! -z "\$SLURM_NODELIST" ];then
     return
fi

export LMOD_SETTARG_CMD=":"
export LMOD_FULL_SETTARG_SUPPORT=no
export LMOD_COLORIZE=no
export LMOD_PREPEND_BLOCK=normal

if [ \$EUID -eq 0 ]; then
    export MODULEPATH=%{?OHPC_MODULES:%{OHPC_ADMIN}/modulefiles:%{OHPC_MODULES}:}%{lua_lmod_admin_modulesdir}:%{lua_lmod_modulesdir}
else
    export MODULEPATH=%{?OHPC_MODULES:%{OHPC_MODULES}:}%{lua_lmod_modulesdir}
fi

export BASH_ENV=%{_datadir}/lmod/%{version}/init/bash

# Initialize modules system
. \${BASH_ENV} >/dev/null

# Load baseline SUSE HPC environment
module try-add suse-hpc

EOF

cat <<EOF >%{buildroot}/%{_sysconfdir}/profile.d/lmod.csh
# -*- shell-script -*-
########################################################################
#  This is the system wide source file for setting up
#  modules:
#
########################################################################

if ( \$?SLURM_NODELIST ) then
    exit 0
endif

setenv LMOD_SETTARG_CMD ":"
setenv LMOD_FULL_SETTARG_SUPPORT "no"
setenv LMOD_COLORIZE "no"
setenv LMOD_PREPEND_BLOCK "normal"

if ( \`id -u\` == "0" ) then
   setenv MODULEPATH "%{?OHPC_MODULES:%{OHPC_ADMIN}/modulefiles:%{OHPC_MODULES}:}%{lua_lmod_admin_modulesdir}:%{lua_lmod_modulesdir}"
else   
   setenv MODULEPATH "%{?OHPC_MODULES:%{OHPC_MODULES}:}%{lua_lmod_modulesdir}"
endif

# Initialize modules system
source %{_datadir}/lmod/%{version}/init/csh >/dev/null

# Load baseline SUSE HPC environment
module try-add suse-hpc 

EOF

%files
%defattr(-,root,root,-)
%config %{_sysconfdir}/profile.d/lmod.sh
%config %{_sysconfdir}/profile.d/lmod.csh
%config %{_sysconfdir}/rpm/macros.lmod
%dir %{_datadir}/lmod
%dir %{lua_lmod_modulesdir}
%dir %{lua_lmod_admin_modulesdir}
%dir %{lua_lmod_moduledeps}
%{_datadir}/lmod/*
%{_mandir}/man1/lmod.1.*
%doc License
%doc README.*

%files doc
%defattr(-,root,root,-)
%doc my_docs/*.txt my_docs/*.pdf my_docs/*.md
%doc docs/build/latex/Lmod.pdf

%changelog
* Wed Apr 18 2018 jengelh@inai.de
- Replace %%__ type macro indirections.
- Update RPM groups, summaries, find|xargs commands.
* Wed Apr 18 2018 eich@suse.com
- Avoid conflicting script snippets from 'Modules' and 'lua-lmod'
  in /etc/profiles.d by making sure that both packages cannot be
  installed simultaneously (boo#1089970).
* Mon Oct 16 2017 eich@suse.com
- Doc-Ugly-workaround-for-bug-in-Sphinx.patch
  On SLE-12 and Leap 42.x Sphinx generates an incorrect tex file.
  This patch adds ugly code to the documentation Makefile to patch
  it up and work around this problem.
* Tue Oct 10 2017 eich@suse.com
- Make lua-lmod Arch-dependent: it hard codes the search path to
  .so plugins used by other Lua packages (boo#1061205).
* Fri Oct  6 2017 eich@suse.com
- Update to 7.6:
    1. Support for disable <collection_name>
    2. A marked default is honored even if it is hidden
    3. Support for depends_on() as a better way to handle module dependencies.
  * Lmod 7.5:
    1. Added -T, --trace option to report restore, load, unloads and spider.
    2. Report both global and version aliases with module --terse
    Add Global Aliases output to module avail if they exist.
    3. Support for isVisibleHook (Thanks @wpoely86!) to control whether
    a module is hidden or not.
    4. Support for "spider -o spider-json" to set the key "hidden"
    to true or false for each module.
    5. Setting LMOD_EXACT_MATCH=yes also turns off the display of (D) with
    avail.
    6. CMake "shell" added.
    7. Added feature that LMOD_TMOD_FIND_FIRST.  A site can decide to force
    FIND_FIRST instead FIND_BEST for NV module layouts.
    Bug Fixes:
    1. Fix bug where Lmod would be unable to load a module where NV and
    NVV module layouts were mixed.
    2. Fix bug where LMOD_CASE_INDEPENDENT_SORTING=yes wasn't case
    independent when using avail hook.
  * Lmod 7.4:
    1. Using built-in luafilesystem if system version doesn't exist or < 1.6.2
    2. Support for setting LMOD_SYSHOST with configure.
    3. Sites or users can use italic instead of dim for hidden modules
    4. Detailed spider output reports all dependencies hidden or not.
    5. Support for fish shell
    6. Move almost all configuration variables from profile.in to bash.in and
    similarly for tcsh.
    Bug Fixes:
    1. Fixed bug that caused LMOD env vars to be lower cased.
    2. Fixed bug where tcsh/csh exit status was not returned.
    3. bash and zsh tab completions works when LMOD_REDIRECT is yes.
    4. Can now conflict with a version.
    5. Fixed bug with addto a:b:c
    6. Fixed bugs in computeHashSum, generating softwarePage.
  * Lmod 7.3:
    1. The isloaded() function has been repaired.
    2. Updated French, German and Spanish translations.
    3. Two error message related to missing modules are now available for
    translations.
  * Lmod 7.2.1:
    1. A test suite for testing the Lmod installation has been added. See
    https://github.com/rtmclay/Lmod_test_suite for details.
    2. Added support for localization of errors and warnings and messages.
    3. Language Translations complete: ES, Partial: FR, ZH, DE
    4. Introduced "errWarnMsgHook" to take advantage of the new message
    handling.
    Bug Fixes:
    1. Several bug fixes related to Spider Cache and LMOD_CACHED_LOADS=1
    2. Repaired zsh tab completion.
    3. Minimize the output of Lmod's BASH_ENV when debugging Bash shell
    scripts.
    4. Allow colons as well as spaces for the path used in the addto command.
    5. Handles module directories that are empty or bad symlink or a .version
    file only.
    6. Fix bug in module describe.
  * Lmod 7.1:
    1. The commands "module --show_hidden avail" and "module --show_hidden"
    list now show "hidden" modules with the (H) property.  Also they are
    displayed as dim.  This works better on black backgrounds.
    2. Added the command "module --config_json" to generate a json output of
    Lmod's configuration.
    3. Add support for env. var. LMOD_SITE_NAME to set a site's name.  This is
    also a configure option.
    Bug Fixes:
    1. Hidden module now will not be marked as default.
    2. Now check permission of a directory before trying to open it.
    3. Lmod now does not pollute the configure time value of LD_LIBRARY_PATH
    and LD_PRELOAD into the users env.
    4. Lmod now handles illegal values of $TERM.
  * Lmod 7.0:
    1. This version support N/V/V. (e.g. fftw/64/3.3.4).  Put a .version file
    in with the "64" directory to tell Lmod where the version starts.
    2. Marking a default in the MODULERC is now supported.
    3. User ~/.modulerc has priority over system MODULERC.
    4. System MODULERC  has priority over marking a default in the module
    tree.
    5. Installed Modules can be hidden by "hide-version foo/3.2.1" in any
    modulerc file.
    6. The system spider cache has changed.  Please update your scripts to
    build spiderT.lua instead of moduleT.lua
  * Lmod 6.6:
    1. Now uses the value of LD_PRELOAD and LD_LIBRARY_PATH found at configure
    time to run all TCL progams.
    2. Now uses a custom _module_dir function for tab completion in bash for
    module use path<TAB>. Thanks to Pieter Neerincx!
    3. Support for LMOD_FAMILY_<name>_VERSION added.
    4. If ~/.lmod.d/.cache/invalidated exists then the user cache file(s) are
    ignored. When generating a user cache file ~/.lmod.d/.cache/invalidated
    is deleted.
    Bug Fixes:
    1. Correctly merges spider cache location where there are multiple
    lmodrc.lua files.
    2. Remove leading and trailing blanks for names in setenv, pushenv,
    prepend_path, etc.
    3. ml now generates error for unknown argument that start with a double
    minus. (e.g. ml --vers)
    4. pushenv("name","") fixed when unloading module.
    5. Make sure to regularize MODULEPATH when ingesting it for the first
    time.
- lmod.consulting.patch replaced by:
  Messages-Remove-message-about-creating-a-consulting-ticket.patch.
- lmod.site.patch:
  Removed: The site name is now provided by the env variable LMOD_SITE_NAME.
  (FATE#324199).
* Thu Oct  5 2017 eich@suse.com
- Fix build for Leap, SLE-12 and SLE-15.
- Remove _service file: the service can be run with
  'osc service run download_files' as well.
* Tue Sep  5 2017 eich@suse.com
- Change group of documentation package to Documentation/Other.
* Mon Aug 14 2017 eich@suse.com
- Fix group of doc package.
- Change BuildRequires from ohpc to ohpc-macros.
* Thu Aug 10 2017 eich@suse.com
- Fix build: add buildrequires for texlive-latexmk, texlive-makeindex and
    texlive-varwidth.
* Thu Aug 10 2017 eich@suse.com
- Prepare for suse default settings (bsc#1053237).
* Mon Jun 26 2017 dmueller@suse.com
- correct buildrequires for building on Leap 42.3 and on SLE15+
* Fri Apr 28 2017 eich@suse.com
- Add profile files for bash and csh (bsc#1048964).
* Fri Apr  7 2017 eich@suse.com
- Build and package man page and other documentation, create a separate
  package for additional documentation (bsc#1032970).
* Thu Feb 16 2017 jengelh@inai.de
- Replace redundant %%__ macro indirections
* Sat Nov 12 2016 eich@suse.com
  * Updated to version 6.5.11:
  - All the Lmod programs now resolve any symlinks to the
  actual program before adding to the Lua's package.path
  and package.cpath.
  - Contrib patch: Extend msgHook to LmodError and LmodWarning
  - Now using travis for CI and testing.
  - Configure time option to have Lmod check for magic TCL string in
  modulefiles (#%%Module)
  - Lmod now uses a regular expression to match user commands
  to internal commands. For example "av", "ava" or "available"
  will match "avail"
  - Lmod now uses the values of LUA_PATH and LUA_CPATH at
  configuration time.  This way Lmod is safe from user changes
  to these important Lua values.
  - Updated documentation at lmod.readthedocs.org
  - Support for generating xalt_rmapT.json used by XALT.
  - Fixed bug with upcase characters in version file.
  - It is now possible to configure Lmod to use the spider cache
  when loading (--with-cachedLoads=yes or
  export LMOD_CACHED_LOADS=1 to activate). This is off by
  default. Sites that use this will have to keep their spider
  caches up-to-date or user will not be able to load modules
  not in the cache.
- It is now possible to configure Lmod to use Legacy Version
  ordering ( --with-legacyOrdering=yes or export
  LMOD_LEGACY_VERSION_ORDERING=1). With legacy ordering 9.0
  is "newer" than 10.0. This is the ordering that Tmod uses.
- Lmod will print admin message (a.k.a nag messages) when
  doing module whatis <foo> or module help <foo>.  In other
  words if a nag message would appear with module load <foo>
  then it will also appear when using whatis or help.
- Many improvement in the generation of the lmod database for
  module tracking.
- Numerous bug fixes.
* Mon Oct 17 2016 eich@suse.com
- Setting 'download_files' service to mode='localonly'
  and adding source tarball. (Required for Factory).
* Wed Oct 12 2016 eich@suse.com
- Initial version of Lmod: 6.0.24
